

#include "stm32f10x.h"
#include "usart.h"



/* select board option */
#ifdef CQ
    #define LED_PORT  GPIOC
    #define LED_BIT   GPIO_Pin_6
#endif

#ifdef STBEE
    #define LED_PORT  GPIOD
    #define LED_BIT   GPIO_Pin_4
#endif

#ifdef STBEE_MINI
    #define LED_PORT  GPIOA
    #define LED_BIT   GPIO_Pin_13
#endif





/* Wait by empty loop */
void Delay(unsigned int nCount)
{
    volatile unsigned int i;
    for(; nCount!= 0;nCount--){
        for(i=0;i<10000;i++);
    }
}


/* Configures the different system clocks. */
void RCC_Configuration(void)
{
    /* Flash Write Enable */
    //FLASH_Unlock();
    
    /* RCC system reset(for debug purpose) */
    RCC_DeInit();
    
    /* Enable Prefetch Buffer */
    FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);
    
    /* Flash 2 wait state */
    FLASH_SetLatency(FLASH_Latency_2);

    /* HCLK = SYSCLK */
    RCC_HCLKConfig(RCC_SYSCLK_Div1);

    /* PCLK2 = HCLK */
    RCC_PCLK2Config(RCC_HCLK_Div1);

    /* PCLK1 = HCLK/2 */
    RCC_PCLK1Config(RCC_HCLK_Div2);
    
    /* ADCCLK = PCLK2/6 10.67MHz */
    RCC_ADCCLKConfig(RCC_PCLK2_Div6); 
    
    /* PLLCLK = 4MHz * 16 = 64 MHz */
    RCC_PLLConfig(RCC_PLLSource_HSI_Div2, RCC_PLLMul_16);

    /* Enable PLL */
    RCC_PLLCmd(ENABLE);

    /* Wait till PLL is ready */
    while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);
    
    /* Select PLL as system clock source */
    RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);
    
    /* Wait till PLL is used as system clock source */
    while(RCC_GetSYSCLKSource() != 0x08);
    
    /* Enable DMA clock */
    RCC_AHBPeriphClockCmd(RCC_AHBENR_DMA1EN, ENABLE);
    
    /* Enable APB1 Peripheral clocks */
    RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM2 | RCC_APB1Periph_TIM3 | RCC_APB1Periph_TIM4, ENABLE);
    
    /* Enable APB2 Peripheral clocks */
    RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA | RCC_APB2Periph_GPIOB | 
                           RCC_APB2Periph_GPIOC | RCC_APB2Periph_GPIOD, ENABLE);
    RCC_APB2PeriphClockCmd(RCC_APB2Periph_AFIO | RCC_APB2Periph_ADC1 | RCC_APB2Periph_ADC2 |
                           RCC_APB2Periph_TIM1 | RCC_APB2Periph_USART1, ENABLE);
    
    
}

void GPIO_Configuration(void)
{
    GPIO_InitTypeDef GPIO_InitStructure;
    
    GPIO_PinRemapConfig(GPIO_Remap_SWJ_Disable, ENABLE);
    //GPIO_PinRemapConfig(GPIO_PartialRemap1_TIM2, ENABLE);
    
    
    /* Configure LED pin as output push-pull */
    GPIO_InitStructure.GPIO_Pin = LED_BIT;
    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
    GPIO_Init(LED_PORT, &GPIO_InitStructure);
    
    /* Configure USART1 Tx (PA.09) as alternate function push-pull */
    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_9;
    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
    GPIO_Init(GPIOA, &GPIO_InitStructure);
    
}

void NVIC_Configuration(void)
{
    NVIC_InitTypeDef NVIC_InitStructure;
    
    #ifdef DFU
        NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x3000);
    #else
        NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0000);
    #endif
    
}

void SystemInit()
{
    RCC_Configuration();
    NVIC_Configuration();
    GPIO_Configuration();
    
    usart_init();
    
}

int main(void)
{
    
    SystemInit();
    
    usart_printstr("Hello World!\n");
    
    while(1){
        
        GPIO_ResetBits(LED_PORT, LED_BIT);
        Delay(100);
        GPIO_SetBits(LED_PORT, LED_BIT);
        Delay(100);
    }
    
    return 0;
}






